@@ -276,7 +276,7 @@ MagickExport MagickBooleanType AnnotateImage(Image *image,
   for (p=text; *p != '\0'; p++)
     if (*p == '\n')
       number_lines++;
-  textlist=AcquireQuantumMemory(number_lines+1,sizeof(*textlist));
+  textlist=(char **) AcquireQuantumMemory(number_lines+1,sizeof(*textlist));
   if (textlist == (char **) NULL)
     {
       annotate_info=DestroyDrawInfo(annotate_info);
@@ -285,7 +285,7 @@ MagickExport MagickBooleanType AnnotateImage(Image *image,
       return(MagickFalse);
     }
   p=text;
-  for (i=0; i < number_lines; i++)
+  for (i=0; i < (ssize_t) number_lines; i++)
   {
     char
       *q;
@@ -1315,6 +1315,7 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
     args;
 
   FT_UInt
+    first_glyph_id,
     last_glyph_id;
 
   FT_Vector
@@ -1485,7 +1486,10 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
     (metrics->pixels_per_em.x/face->units_per_EM);
   metrics->underline_thickness=face->underline_thickness*
     (metrics->pixels_per_em.x/face->units_per_EM);
-  if ((draw_info->text == (char *) NULL) || (*draw_info->text == '\0'))
+  first_glyph_id=0;
+  FT_Get_First_Char(face,&first_glyph_id);
+  if ((draw_info->text == (char *) NULL) || (*draw_info->text == '\0') ||
+      (first_glyph_id == 0))
     {
       (void) FT_Done_Face(face);
       (void) FT_Done_FreeType(library);
@@ -1572,8 +1576,6 @@ static MagickBooleanType RenderFreetype(Image *image,const DrawInfo *draw_info,
       Render UTF-8 sequence.
     */
     glyph.id=(FT_UInt) grapheme[i].index;
-    if (glyph.id == 0)
-      glyph.id=FT_Get_Char_Index(face,' ');
     if ((glyph.id != 0) && (last_glyph_id != 0))
       origin.x+=(FT_Pos) (64.0*draw_info->kerning);
     glyph.origin=origin;
