@@ -764,9 +764,9 @@ MagickExport MagickStatusType ParseAffineGeometry(const char *geometry,
   p=(char *) geometry;
   for (i=0; (*p != '\0') && (i < 6); i++)
   {
-    GetNextToken(p,&p,MagickPathExtent,token);
+    (void) GetNextToken(p,&p,MagickPathExtent,token);
     if (*token == ',')
-      GetNextToken(p,&p,MagickPathExtent,token);
+      (void) GetNextToken(p,&p,MagickPathExtent,token);
     switch (i)
     {
       case 0:
@@ -1424,9 +1424,6 @@ MagickExport MagickStatusType ParseMetaGeometry(const char *geometry,ssize_t *x,
         geometry_ratio,
         image_ratio;
 
-      GeometryInfo
-        geometry_info;
-
       /*
         Geometry is a relative to image size and aspect ratio.
       */
