@@ -17,13 +17,13 @@
 %                                  July 1992                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2018 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    https://www.imagemagick.org/script/license.php                           %
+%    https://imagemagick.org/script/license.php                               %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -290,7 +290,7 @@ static void RadonProjection(const Image *image,MatrixInfo *source_matrixs,
     q=swap;
   }
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) \
+  #pragma omp parallel for schedule(static) \
     magick_number_threads(image,image,GetMatrixColumns(p),1)
 #endif
   for (x=0; x < (ssize_t) GetMatrixColumns(p); x++)
@@ -379,7 +379,7 @@ static MagickBooleanType RadonTransform(const Image *image,
   status=MagickTrue;
   image_view=AcquireVirtualCacheView(image,exception);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,image->rows,1)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
@@ -436,7 +436,7 @@ static MagickBooleanType RadonTransform(const Image *image,
   RadonProjection(image,source_matrixs,destination_matrixs,-1,projection);
   (void) NullMatrix(source_matrixs);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(status) \
+  #pragma omp parallel for schedule(static) shared(status) \
     magick_number_threads(image,image,image->rows,1)
 #endif
   for (y=0; y < (ssize_t) image->rows; y++)
@@ -730,14 +730,27 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
   assert(image != (Image *) NULL);
   page=image->page;
   rotations%=4;
-  if (rotations == 0)
-    return(CloneImage(image,0,0,MagickTrue,exception));
-  if ((rotations == 1) || (rotations == 3))
-    rotate_image=CloneImage(image,image->rows,image->columns,MagickTrue,
-      exception);
-  else
-    rotate_image=CloneImage(image,image->columns,image->rows,MagickTrue,
-      exception);
+  switch (rotations)
+  {
+    case 0:
+    {
+      rotate_image=CloneImage(image,0,0,MagickTrue,exception);
+      break;
+    }
+    case 2:
+    {
+      rotate_image=CloneImage(image,image->columns,image->rows,MagickTrue,
+        exception);
+      break;
+    }
+    case 1:
+    case 3:
+    {
+      rotate_image=CloneImage(image,image->rows,image->columns,MagickTrue,
+        exception);
+      break;
+    }
+  }
   if (rotate_image == (Image *) NULL)
     return((Image *) NULL);
   /*
@@ -745,8 +758,11 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
   */
   status=MagickTrue;
   progress=0;
-  image_view=AcquireVirtualCacheView(image,exception);
-  rotate_view=AcquireAuthenticCacheView(rotate_image,exception);
+  if (rotations != 0)
+    {
+      image_view=AcquireVirtualCacheView(image,exception);
+      rotate_view=AcquireAuthenticCacheView(rotate_image,exception);
+    }
   switch (rotations)
   {
     case 1:
@@ -764,8 +780,8 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
       GetPixelCacheTileSize(image,&tile_width,&tile_height);
       tile_width=image->columns;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-      #pragma omp parallel for schedule(static,4) shared(status) \
-        magick_number_threads(image,image,image->rows/tile_height,1)
+      #pragma omp parallel for schedule(static) shared(status) \
+        magick_number_threads(image,rotate_image,image->rows/tile_height,1)
 #endif
       for (tile_y=0; tile_y < (ssize_t) image->rows; tile_y+=(ssize_t) tile_height)
       {
@@ -830,12 +846,6 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
               register ssize_t
                 i;
 
-              if (GetPixelWriteMask(image,tile_pixels) <= (QuantumRange/2))
-                {
-                  tile_pixels-=width*GetPixelChannels(image);
-                  q+=GetPixelChannels(rotate_image);
-                  continue;
-                }
               for (i=0; i < (ssize_t) GetPixelChannels(image); i++)
               {
                 PixelChannel channel = GetPixelChannelChannel(image,i);
@@ -860,9 +870,6 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
             MagickBooleanType
               proceed;
 
-#if defined(MAGICKCORE_OPENMP_SUPPORT)
-            #pragma omp critical (MagickCore_IntegralRotateImage)
-#endif
             proceed=SetImageProgress(image,RotateImageTag,progress+=tile_height,
               image->rows);
             if (proceed == MagickFalse)
@@ -886,8 +893,8 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
         Rotate 180 degrees.
       */
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-      #pragma omp parallel for schedule(static,4) shared(status) \
-        magick_number_threads(image,image,image->rows,1)
+      #pragma omp parallel for schedule(static) shared(status) \
+        magick_number_threads(image,rotate_image,image->rows,1)
 #endif
       for (y=0; y < (ssize_t) image->rows; y++)
       {
@@ -920,11 +927,6 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
             i;
 
           q-=GetPixelChannels(rotate_image);
-          if (GetPixelWriteMask(image,p) <= (QuantumRange/2))
-            {
-              p+=GetPixelChannels(image);
-              continue;
-            }
           for (i=0; i < (ssize_t) GetPixelChannels(image); i++)
           {
             PixelChannel channel = GetPixelChannelChannel(image,i);
@@ -946,9 +948,6 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
             MagickBooleanType
               proceed;
 
-#if defined(MAGICKCORE_OPENMP_SUPPORT)
-            #pragma omp critical (MagickCore_IntegralRotateImage)
-#endif
             proceed=SetImageProgress(image,RotateImageTag,progress++,
               image->rows);
             if (proceed == MagickFalse)
@@ -978,8 +977,8 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
       GetPixelCacheTileSize(image,&tile_width,&tile_height);
       tile_width=image->columns;
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-      #pragma omp parallel for schedule(static,4) shared(status) \
-        magick_number_threads(image,image,image->rows/tile_height,1)
+      #pragma omp parallel for schedule(static) shared(status) \
+        magick_number_threads(image,rotate_image,image->rows/tile_height,1)
 #endif
       for (tile_y=0; tile_y < (ssize_t) image->rows; tile_y+=(ssize_t) tile_height)
       {
@@ -1043,12 +1042,6 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
               register ssize_t
                 i;
 
-              if (GetPixelWriteMask(image,tile_pixels) <= (QuantumRange/2))
-                {
-                  tile_pixels+=width*GetPixelChannels(image);
-                  q+=GetPixelChannels(rotate_image);
-                  continue;
-                }
               for (i=0; i < (ssize_t) GetPixelChannels(image); i++)
               {
                 PixelChannel channel = GetPixelChannelChannel(image,i);
@@ -1093,8 +1086,11 @@ MagickExport Image *IntegralRotateImage(const Image *image,size_t rotations,
     default:
       break;
   }
-  rotate_view=DestroyCacheView(rotate_view);
-  image_view=DestroyCacheView(image_view);
+  if (rotations != 0)
+    {
+      rotate_view=DestroyCacheView(rotate_view);
+      image_view=DestroyCacheView(image_view);
+    }
   rotate_image->type=image->type;
   rotate_image->page=page;
   if (status == MagickFalse)
@@ -1177,7 +1173,7 @@ static MagickBooleanType XShearImage(Image *image,const double degrees,
   progress=0;
   image_view=AcquireAuthenticCacheView(image,exception);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(progress,status) \
+  #pragma omp parallel for schedule(static) shared(progress,status) \
     magick_number_threads(image,image,height,1)
 #endif
   for (y=0; y < (ssize_t) height; y++)
@@ -1307,9 +1303,10 @@ static MagickBooleanType XShearImage(Image *image,const double degrees,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-        #pragma omp critical (MagickCore_XShearImage)
+        #pragma omp atomic
 #endif
-        proceed=SetImageProgress(image,XShearImageTag,progress++,height);
+        progress++;
+        proceed=SetImageProgress(image,XShearImageTag,progress,height);
         if (proceed == MagickFalse)
           status=MagickFalse;
       }
@@ -1393,14 +1390,11 @@ static MagickBooleanType YShearImage(Image *image,const double degrees,
   background=image->background_color;
   image_view=AcquireAuthenticCacheView(image,exception);
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-  #pragma omp parallel for schedule(static,4) shared(progress,status) \
+  #pragma omp parallel for schedule(static) shared(progress,status) \
     magick_number_threads(image,image,width,1)
 #endif
   for (x=0; x < (ssize_t) width; x++)
   {
-    ssize_t
-      step;
-
     double
       area,
       displacement;
@@ -1420,6 +1414,9 @@ static MagickBooleanType YShearImage(Image *image,const double degrees,
     ShearDirection
       direction;
 
+    ssize_t
+      step;
+
     if (status == MagickFalse)
       continue;
     p=GetCacheViewAuthenticPixels(image_view,x_offset+x,0,1,image->rows,
@@ -1525,9 +1522,10 @@ static MagickBooleanType YShearImage(Image *image,const double degrees,
           proceed;
 
 #if defined(MAGICKCORE_OPENMP_SUPPORT)
-        #pragma omp critical (MagickCore_YShearImage)
+        #pragma omp atomic
 #endif
-        proceed=SetImageProgress(image,YShearImageTag,progress++,image->rows);
+        progress++;
+        proceed=SetImageProgress(image,YShearImageTag,progress,image->rows);
         if (proceed == MagickFalse)
           status=MagickFalse;
       }
@@ -1742,7 +1740,7 @@ MagickExport Image *ShearRotateImage(const Image *image,const double degrees,
     (void) LogMagickEvent(TraceEvent,GetMagickModule(),"%s",image->filename);
   assert(exception != (ExceptionInfo *) NULL);
   assert(exception->signature == MagickCoreSignature);
-  angle=degrees-360.0*(ssize_t) (degrees/360.0);
+  angle=fmod(degrees,360.0);
   if (angle < -45.0)
     angle+=360.0;
   for (rotations=0; angle > 45.0; rotations++)
