@@ -2,7 +2,7 @@
   Copyright 1999-2019 ImageMagick Studio LLC, a non-profit organization
   dedicated to making software imaging solutions freely available.
   
-  You may not use this file except in compliance with the License.
+  You may not use this file except in compliance with the License.  You may
   obtain a copy of the License at
   
     https://imagemagick.org/script/license.php
@@ -20,7 +20,8 @@
 
 #define MagickRGBAliases \
   MagickCoderAlias("RGB", "RGBA") \
-  MagickCoderAlias("RGB", "RGBO")
+  MagickCoderAlias("RGB", "RGBO") \
+  MagickCoderAlias("RGB", "RGB565")
 
 #if defined(__cplusplus) || defined(c_plusplus)
 extern "C" {
@@ -30,4 +31,4 @@ MagickCoderExports(RGB)
 
 #if defined(__cplusplus) || defined(c_plusplus)
 }
-#endif
\ No newline at end of file
+#endif
